Commit e077739b69cac20c9ed95095e5d7d6c614a36b6b

henry 2001-10-30T23:23:29

Renamed functions in prep for extruded glyphs Ingest->Process Output->MakeOutline

diff --git a/src/FTOutlineGlyph.cpp b/src/FTOutlineGlyph.cpp
index 67d0919..b20ba3f 100644
--- a/src/FTOutlineGlyph.cpp
+++ b/src/FTOutlineGlyph.cpp
@@ -20,7 +20,7 @@ FTOutlineGlyph::FTOutlineGlyph( FT_Glyph glyph)
 
 	vectoriser = new FTVectoriser( glyph);
 	
-	vectoriser->Ingest();
+	vectoriser->Process();
 	numContours = vectoriser->contours();
 	contourLength = new int[ numContours];
 	
@@ -31,7 +31,7 @@ FTOutlineGlyph::FTOutlineGlyph( FT_Glyph glyph)
 	
 	numPoints = vectoriser->points();
 	data = new double[ numPoints * 3];
-	vectoriser->Output( data);
+	vectoriser->MakeOutline( data);
 	
 	advance = glyph->advance.x >> 16;
 
diff --git a/src/FTPolyGlyph.cpp b/src/FTPolyGlyph.cpp
index 509f6e7..7b372cb 100644
--- a/src/FTPolyGlyph.cpp
+++ b/src/FTPolyGlyph.cpp
@@ -59,7 +59,7 @@ FTPolyGlyph::FTPolyGlyph( FT_Glyph glyph)
 
 	vectoriser = new FTVectoriser( glyph);
 	
-	vectoriser->Ingest();
+	vectoriser->Process();
 	numContours = vectoriser->contours();
 	contourLength = new int[ numContours];
 	
@@ -70,7 +70,8 @@ FTPolyGlyph::FTPolyGlyph( FT_Glyph glyph)
 	
 	numPoints = vectoriser->points();
 	data = new double[ numPoints * 3];
-	vectoriser->Output( data);
+	// FIXME MakeMesh
+	vectoriser->MakeOutline( data);
 	
 	contourFlag = vectoriser->ContourFlag();
 	advance = glyph->advance.x >> 16;
diff --git a/src/FTVectoriser.cpp b/src/FTVectoriser.cpp
index 27e98a2..de26a18 100644
--- a/src/FTVectoriser.cpp
+++ b/src/FTVectoriser.cpp
@@ -62,7 +62,7 @@ int FTVectoriser::points()
 }
 
 
-bool FTVectoriser::Ingest()
+bool FTVectoriser::Process()
 {
 	short first = 0;
 	short last;
@@ -208,7 +208,7 @@ void FTVectoriser::evaluateCurve( const int n)
 }
 
 
-void FTVectoriser::Output( double* data)
+void FTVectoriser::MakeOutline( double* data)
 {
 	int i = 0;
 	
@@ -225,3 +225,4 @@ void FTVectoriser::Output( double* data)
 		}
 	}
 }
+
diff --git a/include/FTVectoriser.h b/include/FTVectoriser.h
index ef69076..1e5669d 100644
--- a/include/FTVectoriser.h
+++ b/include/FTVectoriser.h
@@ -160,13 +160,13 @@ class FTGL_EXPORT FTVectoriser
 		 *
 		 * @return <code>true</code> on success
 		 */
-		bool Ingest();
+		bool Process();
 
 		/**
 		 * Copy the point data into a block of <code>doubles</code>
 		 * @param d
 		 */
-		void Output( double* d);
+		void MakeOutline( double* d);
 
 		/**
 		 * Get the total count of points in this outline
@@ -160,13 +160,13 @@ class FTGL_EXPORT FTVectoriser
 
 		/**
-		 * Copy the point data into a block of <code>doubles</code>
+		 * Copy the outline data into a block of <code>doubles</code>
 		 * @param d
 		 */